summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepasswordedaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepasswordedaccount.h')
-rw-r--r--kopete/libkopete/kopetepasswordedaccount.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/kopete/libkopete/kopetepasswordedaccount.h b/kopete/libkopete/kopetepasswordedaccount.h
index dbec92db..a9fa2f54 100644
--- a/kopete/libkopete/kopetepasswordedaccount.h
+++ b/kopete/libkopete/kopetepasswordedaccount.h
@@ -35,30 +35,31 @@ class Password;
class KOPETE_EXPORT PasswordedAccount : public Account
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* KopetePasswordedAccount constructor
* @param parent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
- * @param name The name for this QObject
+ * @param name The name for this TQObject
*
* @deprecated Use the constructor that specifies if a blank password is allowed
*/
- PasswordedAccount( Protocol *parent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
+ PasswordedAccount( Protocol *tqparent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
/**
* KopetePasswordedAccount constructor
* @param parent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
* @param allowBlankPassword If this protocol allows blank passwords. Note that this will mean that
*
- * @param name The name for this QObject
+ * @param name The name for this TQObject
*/
- PasswordedAccount( Protocol *parent, const TQString &acctId, uint maxPasswordLength = 0,
+ PasswordedAccount( Protocol *tqparent, const TQString &acctId, uint maxPasswordLength = 0,
bool allowBlankPassword = false, const char *name = 0 );
virtual ~PasswordedAccount();
@@ -73,15 +74,15 @@ public:
/**
* @brief Go online for this service.
*
* @param initialStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/
- void connect( const OnlineStatus& initialStatus );
+ void connect( const OnlineStatus& initialtqStatus );
/**
* \brief Get the initial status
*/
- OnlineStatus initialStatus();
+ OnlineStatus initialtqStatus();
/**
* @brief Remove the account from the server.
@@ -97,7 +98,7 @@ public:
public slots:
/**
* Called when your account should attempt to connect.
- * @param password The password to connect with, or TQString::null
+ * @param password The password to connect with, or TQString()
* if the user wished to cancel the connection attempt.
*/
virtual void connectWithPassword( const TQString &password ) = 0;
@@ -35,30 +35,31 @@ class Password;
/**
* KopetePasswordedAccount constructor
- * @param parent The protocol this account connects via
+ * @param tqparent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
@@ -35,30 +35,31 @@ class Password;
/**
* KopetePasswordedAccount constructor
- * @param parent The protocol this account connects via
+ * @param tqparent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
@@ -73,15 +74,15 @@ public:
* @brief Go online for this service.
*
- * @param initialStatus is the status to connect with. If it is an invalid status for this
+ * @param initialtqStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/